==> blanco.plugin.csv_0.7.0-src.zip: blancoCsvPlugin/src/blanco/plugin/csv/wizards/BlancoCsvWizardPage2.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.csv.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

/**
 * vOCEBU[h̃y[W̃NXłB
 * 
 * @author IGA Tosiki
 */
public class BlancoCsvWizardPage2 extends WizardPage {
    public BlancoCsvWizardPage2(ISelection selection) {
        super("wizardPage");
        setTitle("blancoCsv̏Љ");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE).setText("blancoCsv ͉L̂悤ȃc[łB");
        new Label(container, SWT.NONE).setText("  1.\[XR[h^Cv");
        new Label(container, SWT.NONE)
                .setText("    CSVt@Co͂̂߂̃ANZTJava/C#.NET\[XR[h܂B");
        new Label(container, SWT.NONE)
                .setText("    sɓ̃Cu(*.jar)t@CKvƂ܂B");
        new Label(container, SWT.NONE).setText("  2.hLgw");
        new Label(container, SWT.NONE).setText("    t@C`(CSV)͂Ƃē삵܂B");
        new Label(container, SWT.NONE)
                .setText("    hLgwł邽߁AhLgƃ\[XR[hƂ̓RɎ邱Ƃo܂B");

        setControl(container);
    }
}

==> blanco.plugin.csv_1.2.3-src.zip: blancoCsvPlugin/src/blanco/plugin/csv/wizards/BlancoCsvWizardPage2.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.csv.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.csv.BlancoCsvConstants;
import blanco.csv.resourcebundle.BlancoCsvResourceBundle;

/**
 * vOCEBU[h̃y[W̃NXłB
 * 
 * @author IGA Tosiki
 */
public class BlancoCsvWizardPage2 extends WizardPage {
    private static final BlancoCsvResourceBundle fBundle = new BlancoCsvResourceBundle();

    public BlancoCsvWizardPage2(ISelection selection) {
        super("wizardPage");
        setTitle(BlancoCsvConstants.PRODUCT_NAME + "̏Љ");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE).setText(BlancoCsvConstants.PRODUCT_NAME
                + " ͉L̂悤ȃc[łB");
        new Label(container, SWT.NONE).setText("  1.\[XR[h^Cv");
        new Label(container, SWT.NONE)
                .setText("    CSVt@Co͂̂߂̃ANZTJava/C#.NET\[XR[h܂B");
        new Label(container, SWT.NONE)
                .setText("    sɓ̃Cu(*.jar)t@CKvƂ܂B");
        new Label(container, SWT.NONE).setText("  2.hLgw");
        new Label(container, SWT.NONE).setText("    "
                + fBundle.getMetafileDisplayname() + "͂Ƃē삵܂B");
        new Label(container, SWT.NONE)
                .setText("    hLgwł邽߁AhLgƃ\[XR[hƂ̓RɎ邱Ƃo܂B");

        setControl(container);
    }
}
